@@ -4,17 +4,10 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from sys import stderr
-from time import sleep as time_sleep
 from typing import Dict, List, Optional
 
 from contracts import contract
-
-try:
-    import vlc  # noqa: F401
-except OSError:
-    print("vlc not found.", file=stderr)
-    exit(1)
+from ymplayer import Player
 
 from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
 
@@ -48,10 +41,9 @@ class Sound:
     def __post_init__(self) -> None:
         self.sound_filename = get_real_sound_filename(self.sound_filename)
 
-    def run(self) -> vlc.MediaPlayer:
-        p = vlc.MediaPlayer(self.sound_filename)
+    def play(self):
+        p = Player(self.sound_filename)
         p.play()
-        return p
 
     @classmethod
     def from_dict(cls, json: dict) -> Sound:
@@ -64,14 +56,6 @@ class Sound:
         return self.message == other.message and self.sound_filename == other.sound_filename
 
 
-def any_ended_sounds(ps: List[vlc.MediaPlayer]) -> bool:
-    for p in ps:
-        if p.get_state() != vlc.State.Ended:
-            return False
-
-    return True
-
-
 @dataclass
 class ClockTimer:
     sounds: Dict[int, Sound]  # Dict from sec to sound
@@ -98,10 +82,7 @@ class ClockTimer:
                 spend_sec=spend_sec,
                 is_first=sec == 0 and count == 1)
 
-            ps.append(sound.run())
-
-        while not any_ended_sounds(ps):
-            time_sleep(1)
+            ps.append(sound.play())
 
     def run(self) -> None:
         count = 1
