@@ -128,11 +128,7 @@ def get_real_json_filename(path: str) -> str:
         if filename.exists():
             return str(filename)
 
-    while path.startswith("_"):
-        path = path[1:]
-    path = str(CLOCK_DIR_IN_PROG / path)
-
-    return path
+    return str(CLOCK_DIR_IN_PROG / path)
 
 
 def get_real_sound_filename(path_: Optional[str]) -> str:
@@ -148,11 +144,7 @@ def get_real_sound_filename(path_: Optional[str]) -> str:
         if filename.exists():
             return str(filename)
 
-    path_name = str(path)
-    while path_name.startswith("_"):
-        path_name = path_name[1:]
-
-    return str(SOUND_DIR_IN_PROG / path_name)
+    return str(SOUND_DIR_IN_PROG / str(path))
 
 
 def notify(title: str, message: str, cmd_io=None) -> None:
